@@ -47,7 +47,7 @@ DEALINGS IN THE SOFTWARE.
 
 extern "C"
 {
-	TQWidget* allocate_tdestyle_config(TQWidget* parent)
+	KDE_EXPORT TQWidget* allocate_tdestyle_config(TQWidget* parent)
 	{
 		TDEGlobal::locale()->insertCatalogue("tdestyle_lipstik_config");
 		return new LipstikStyleConfig(parent);
@@ -130,7 +130,7 @@ LipstikStyleConfig::LipstikStyleConfig(TQWidget* parent): TQWidget(parent)
 
         scrollBarStyleLabel = new TQLabel(scrollGrp);
         scrollBarStyleLabel->setText(i18n("Scrollbar style :       "));
-	scrollBarStyle = new TQComboBox(i18n("Scrollbar style"), scrollGrp);
+	scrollBarStyle = new TQComboBox(i18n("Scrollbar style").utf8(), scrollGrp);
 	scrollBarStyle->setEditable(false);
 	scrollBarStyle->insertItem("Windows style");
 	scrollBarStyle->insertItem("Platinum style");
@@ -139,7 +139,7 @@ LipstikStyleConfig::LipstikStyleConfig(TQWidget* parent): TQWidget(parent)
 
         scrollBarWidthLabel = new TQLabel(scrollGrp);
         scrollBarWidthLabel->setText(i18n("Scrollbar width :       "));
-	scrollBarWidth = new TQComboBox(i18n("Scrollbar width"), scrollGrp);
+	scrollBarWidth = new TQComboBox(i18n("Scrollbar width").utf8(), scrollGrp);
 	scrollBarWidth->setEditable(false);
 	scrollBarWidth->insertItem("Small");
 	scrollBarWidth->insertItem("Normal");
@@ -147,7 +147,7 @@ LipstikStyleConfig::LipstikStyleConfig(TQWidget* parent): TQWidget(parent)
 
         sliderStyleLabel = new TQLabel(scrollGrp);
         sliderStyleLabel->setText(i18n("Slider handle size :       "));
-	sliderStyle = new TQComboBox(i18n("Slider handle size"), scrollGrp);
+	sliderStyle = new TQComboBox(i18n("Slider handle size").utf8(), scrollGrp);
 	sliderStyle->setEditable(false);
 	sliderStyle->insertItem("Small");
 	sliderStyle->insertItem("Medium");
@@ -402,42 +402,42 @@ LipstikStyleConfig::LipstikStyleConfig(TQWidget* parent): TQWidget(parent)
 	origTabHighlightColor = s.readEntry("/lipstikstyle/Settings/tabHighlightColor", "/TQt/KWinPalette/activeBackground");
 	tabHighlightColor->setColor(origTabHighlightColor);
 
-	connect(reverseGradients, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(paintGroove, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(sharperMenuGradient, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(alterMenuGradients, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(menuLeftSideBar, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(flatStripe, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawStatusBarFrame, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawToolBarHandle, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(comboboxColored, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(coloredMenuBar, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawTabHighlight, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(menuSpacing, TQT_SIGNAL( valueChanged(int) ), TQT_SLOT( updateChanged() ) );
-	connect(toolBarSpacing, TQT_SIGNAL( valueChanged(int) ), TQT_SLOT( updateChanged() ) );
-	connect(scrollBarStyle, TQT_SIGNAL( activated(int) ), TQT_SLOT( updateChanged() ) );
-	connect(scrollBarWidth, TQT_SIGNAL( activated(int) ), TQT_SLOT( updateChanged() ) );
-	connect(sliderStyle, TQT_SIGNAL( activated(int) ), TQT_SLOT( updateChanged() ) );
-	connect(animateProgressBar, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawToolBarSeparator, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawToolBarGradient, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(invertBarGrad, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawToolBarItemSeparator, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
- 	connect(drawFocusRect, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
- 	connect(flatHeaders, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
- 	connect(tickCheckMark, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(drawTriangularExpander, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(inputFocusHighlight, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(customOverHighlightColor, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(overHighlightColor, TQT_SIGNAL( pressed() ), TQT_SLOT( updateChanged() ) );
-	connect(customMenuStripeColor, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(menuStripeColor, TQT_SIGNAL( pressed() ), TQT_SLOT( updateChanged() ) );
-	connect(customFocusHighlightColor, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(focusHighlightColor, TQT_SIGNAL( pressed() ), TQT_SLOT( updateChanged() ) );
-	connect(customCheckMarkColor, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(checkMarkColor, TQT_SIGNAL( pressed() ), TQT_SLOT( updateChanged() ) );
-	connect(customTabHighlightColor, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( updateChanged() ) );
-	connect(tabHighlightColor, TQT_SIGNAL( pressed() ), TQT_SLOT( updateChanged() ) );
+	connect(reverseGradients, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(paintGroove, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(sharperMenuGradient, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(alterMenuGradients, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(menuLeftSideBar, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(flatStripe, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawStatusBarFrame, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawToolBarHandle, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(comboboxColored, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(coloredMenuBar, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawTabHighlight, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(menuSpacing, TQ_SIGNAL( valueChanged(int) ), TQ_SLOT( updateChanged() ) );
+	connect(toolBarSpacing, TQ_SIGNAL( valueChanged(int) ), TQ_SLOT( updateChanged() ) );
+	connect(scrollBarStyle, TQ_SIGNAL( activated(int) ), TQ_SLOT( updateChanged() ) );
+	connect(scrollBarWidth, TQ_SIGNAL( activated(int) ), TQ_SLOT( updateChanged() ) );
+	connect(sliderStyle, TQ_SIGNAL( activated(int) ), TQ_SLOT( updateChanged() ) );
+	connect(animateProgressBar, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawToolBarSeparator, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawToolBarGradient, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(invertBarGrad, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawToolBarItemSeparator, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+ 	connect(drawFocusRect, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+ 	connect(flatHeaders, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+ 	connect(tickCheckMark, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(drawTriangularExpander, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(inputFocusHighlight, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(customOverHighlightColor, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(overHighlightColor, TQ_SIGNAL( pressed() ), TQ_SLOT( updateChanged() ) );
+	connect(customMenuStripeColor, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(menuStripeColor, TQ_SIGNAL( pressed() ), TQ_SLOT( updateChanged() ) );
+	connect(customFocusHighlightColor, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(focusHighlightColor, TQ_SIGNAL( pressed() ), TQ_SLOT( updateChanged() ) );
+	connect(customCheckMarkColor, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(checkMarkColor, TQ_SIGNAL( pressed() ), TQ_SLOT( updateChanged() ) );
+	connect(customTabHighlightColor, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( updateChanged() ) );
+	connect(tabHighlightColor, TQ_SIGNAL( pressed() ), TQ_SLOT( updateChanged() ) );
 
 	//Menu Stripe 
 	if ( menuLeftSideBar->isChecked() ) {
@@ -695,13 +695,13 @@ TQString LipstikStyleConfig::scrollBarType( int listnr )
 
 int LipstikStyleConfig::scrollBarItem( TQString kSBType )
 {
-    if( !strcmp(kSBType,"WindowsStyleScrollBar") )
+    if( !strcmp(kSBType.latin1(), "WindowsStyleScrollBar") )
         return 0;
-    else if( !strcmp(kSBType,"PlatinumStyleScrollBar") )
+    else if( !strcmp(kSBType.latin1(), "PlatinumStyleScrollBar") )
         return 1;
-    else if( !strcmp(kSBType,"ThreeButtonScrollBar") )
+    else if( !strcmp(kSBType.latin1(), "ThreeButtonScrollBar") )
         return 2;
-    else if( !strcmp(kSBType,"NextStyleScrollBar") )
+    else if( !strcmp(kSBType.latin1(), "NextStyleScrollBar") )
         return 3;
     else
         return 1;
@@ -724,11 +724,11 @@ TQString LipstikStyleConfig::scrollBarWidthType( int widthListnr )
 
 int LipstikStyleConfig::scrollBarWidthItem( TQString kSBWidthType )
 {
-    if( !strcmp(kSBWidthType,"Small") )
+    if( !strcmp(kSBWidthType.latin1(), "Small") )
         return 0;
-    else if( !strcmp(kSBWidthType,"Normal") )
+    else if( !strcmp(kSBWidthType.latin1(), "Normal") )
         return 1;
-    else if( !strcmp(kSBWidthType,"Large") )
+    else if( !strcmp(kSBWidthType.latin1(), "Large") )
         return 2;
     else
         return 0;
@@ -737,11 +737,11 @@ int LipstikStyleConfig::scrollBarWidthItem( TQString kSBWidthType )
 //Slider types
 int LipstikStyleConfig::sliderItem( TQString kSliderType )
 {
-    if( !strcmp(kSliderType,"sliderPlastikStyle") )
+    if( !strcmp(kSliderType.latin1(), "sliderPlastikStyle") )
         return 0;
-    else if( !strcmp(kSliderType,"sliderLipstikStyle") )
+    else if( !strcmp(kSliderType.latin1(), "sliderLipstikStyle") )
         return 1;
-    else if( !strcmp(kSliderType,"sliderGtkStyle") )
+    else if( !strcmp(kSliderType.latin1(), "sliderGtkStyle") )
         return 2;
     else
         return 2;
